package com.game.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.game.common.core.domain.R;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.game.common.annotation.Log;
import com.game.common.core.controller.BaseController;
import com.game.common.core.domain.AjaxResult;
import com.game.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.game.business.domain.CfgCommon;
import com.game.business.service.ICfgCommonService;
import com.game.common.utils.poi.ExcelUtil;
import com.game.common.core.page.TableDataInfo;

/**
 * 公共配置Controller
 * 
 * @author game
 * @date 2024-07-13
 */
@RestController
@RequestMapping("/business/common")
@Api(value = "CfgCommonController", description = "公共配置接口", tags = {"公共配置"})
public class CfgCommonController extends BaseController
{
    @Autowired
    private ICfgCommonService cfgCommonService;

    /**
     * 查询公共配置列表
     */
    @PreAuthorize("@ss.hasPermi('business:common:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询公共配置列表", notes = "获取公共配置列表")
    public TableDataInfo<CfgCommon> list(CfgCommon cfgCommon)
    {
        startPage();
        List<CfgCommon> list = cfgCommonService.selectCfgCommonList(cfgCommon);
        return getDataTable(list);
    }

    /**
     * 导出公共配置列表
     */
    @PreAuthorize("@ss.hasPermi('business:common:export')")
    @Log(title = "公共配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出公共配置列表", notes = "导出公共配置列表")
    public void export(HttpServletResponse response, CfgCommon cfgCommon)
    {
        List<CfgCommon> list = cfgCommonService.selectCfgCommonList(cfgCommon);
        ExcelUtil<CfgCommon> util = new ExcelUtil<CfgCommon>(CfgCommon.class);
        util.exportExcel(response, list, "公共配置数据");
    }

    /**
     * 获取公共配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:common:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取公共配置详细信息", notes = "获取公共配置详细信息")
    public R<CfgCommon> getInfo(@PathVariable("id") Long id)
    {
        return R.ok(cfgCommonService.selectCfgCommonById(id));
    }

    /**
     * 新增公共配置
     */
    @PreAuthorize("@ss.hasPermi('business:common:add')")
    @Log(title = "公共配置", businessType = BusinessType.INSERT)
    @ApiOperation(value = "新增公共配置", notes = "新增公共配置")
    @PostMapping
    public R add(@RequestBody CfgCommon cfgCommon)
    {
        return R.ok(cfgCommonService.insertCfgCommon(cfgCommon));
    }

    /**
     * 修改公共配置
     */
    @PreAuthorize("@ss.hasPermi('business:common:edit')")
    @Log(title = "公共配置", businessType = BusinessType.UPDATE)
    @ApiOperation(value = "修改公共配置", notes = "修改公共配置")
    @PutMapping
    public R edit(@RequestBody CfgCommon cfgCommon)
    {
        return R.ok(cfgCommonService.updateCfgCommon(cfgCommon));
    }

    /**
     * 删除公共配置
     */
    @PreAuthorize("@ss.hasPermi('business:common:remove')")
    @Log(title = "公共配置", businessType = BusinessType.DELETE)
    @ApiOperation(value = "删除公共配置", notes = "删除公共配置")
	@DeleteMapping("/{ids}")
    public R remove(@PathVariable Long[] ids)
    {
        return R.ok(cfgCommonService.deleteCfgCommonByIds(ids));
    }
}
