package com.game.business.task;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.dynamic.datasource.annotation.DSTransactional;
import com.game.business.domain.*;
import com.game.business.service.*;
import com.game.business.util.im.TencentCloudImUtil;
import com.game.business.vo.AppGameItemBettingVO;
import com.game.common.constant.finance.FinTranType1;
import com.game.common.constant.finance.FinTranType2;
import com.game.common.constant.finance.FinTranType3;
import com.game.common.core.redis.RedisCache;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

@Component
public class AppGameLotteryTask {

    @Autowired
    private IAppGameBettingService appGameBettingService;

    @Autowired
    private IAppUserService appUserService;

    @Autowired
    private IFinTranRecordService finTranRecordService;

    @Autowired
    private IAppGameItemService appGameItemService;

    @Autowired
    private IAppUserCountService appUserCountService;

    @Autowired
    private RedisCache redisCache;

    @Autowired
    private AppUserCountTask appUserCountTask;

    public void updateLottery(AppGameLottery appGameLottery) throws Exception {

        updateItme(appGameLottery.getGameId(), appGameLottery.getGameLotterySucc());

        List<String> userIds = gameBettingTask(appGameLottery);

        appUserCountService.staticsUserCount(appGameLottery.getGameId(),null,appGameLottery.getGameDate());

        // 给中奖人发送刷新余额通知
        sendMsg(userIds);

        //更新可提现余额
        for(String userId : userIds) {
            appUserCountTask.updateWithdrawAble(Long.parseLong(userId));
        }
    }

    private void updateItme(Long gameId, String gameLotterySucc){

        // 修改游戏选项
        String [] bettingItems = gameLotterySucc.split(",");

        for(int j = 0; j < bettingItems.length; j++) {
            String bettingItemStr = bettingItems[j];

            AppGameItem appGameItem = new AppGameItem();
            appGameItem.setGameId(gameId);
            appGameItem.setItemLocation(bettingItemStr);
            // 开奖次数
            appGameItemService.updateLotteryCount(appGameItem);
        }
    }

    @DSTransactional
    private List<String> gameBettingTask(AppGameLottery appGameLottery) throws Exception {

        // 获取未开奖的投注记录
        List<AppGameBetting> list = appGameBettingService.getIsWinning(appGameLottery.getClassId(), appGameLottery.getGameId(), appGameLottery.getGameDate(), 0);

        List<String> userIds = new ArrayList<>();

        if(list == null || list.isEmpty()){
            return userIds;
        }

        for (int i = 0; i < list.size(); i++) {
            AppGameBetting appGameBetting = list.get(i);
            appGameBetting.setUpdateTime(new Date());

            String [] bettingItems = appGameLottery.getGameLotterySucc().split(",");
            List<String> bettingItemsList = Arrays.asList(bettingItems);

            double bettingAmount = appGameBetting.getBettingAmount() * appGameBetting.getBettingMultiple();
            bettingAmount = new BigDecimal(bettingAmount + "").setScale(4, RoundingMode.DOWN).doubleValue();

            if(appGameBetting.getBettingGameType() == 0){
                if(!bettingItemsList.contains(appGameBetting.getBettingItem())){
                    appGameBetting.setIsWinning(2);
                    appGameBettingService.updateById(appGameBetting);
                    continue;
                }
            }else if(appGameBetting.getBettingGameType() == 1 || appGameBetting.getBettingGameType() == 2){
                List<AppGameItemBettingVO> itemList = JSON.parseArray(appGameBetting.getBettingItem(), AppGameItemBettingVO.class);
                if(itemList == null || itemList.isEmpty()){
                    appGameBetting.setIsWinning(2);
                    appGameBettingService.updateById(appGameBetting);
                    continue;
                }
                List<String> bettingItemList = itemList.stream().map(AppGameItemBettingVO::getBettingItem).collect(Collectors.toList());
                boolean isWinning = false;
                for (int j = 0; j < bettingItemList.size(); j++) {
                    String bettingItemStr = bettingItemList.get(j);
                    if(bettingItemsList.contains(bettingItemStr)){
                        isWinning = true;
                        break;
                    }
                }

                if(!isWinning){
                    appGameBetting.setIsWinning(2);
                    appGameBettingService.updateById(appGameBetting);
                    continue;
                }

                if(appGameBetting.getBettingGameType() == 2){
                    for (int k = 0; k < itemList.size(); k++) {
                        AppGameItemBettingVO appGameItemBettingVO = itemList.get(k);
                        if(bettingItemsList.contains(appGameItemBettingVO.getBettingItem())){
                            bettingAmount = appGameBetting.getBettingAmount() * appGameItemBettingVO.getBettingMultiple();
                            bettingAmount = new BigDecimal(bettingAmount + "").setScale(4, RoundingMode.DOWN).doubleValue();
                            break;
                        }
                    }
                }
            }

            AppUser appUser = appUserService.selectAppUserByUserid(appGameBetting.getUserId());
            if(appUser == null){
                appGameBetting.setIsWinning(1);
                appGameBettingService.updateById(appGameBetting);
                continue;
            }

            // 添加推送消息用户
            String userId = appUser.getUserid() + "";
            if(!userIds.contains(userId)){
                userIds.add(userId);
            }

            // 更新用户余额
            //if(appGameBetting.getBettingType() == 0){
            //    appUser.setDiamondCoin(appUser.getDiamondCoin() + bettingAmount );
            //    appUser.setDiamondCoinTotal(appUser.getDiamondCoinCashTotal() + bettingAmount);
            //    appUser.setDiamondCoinCash(appUser.getDiamondCoinCash() + bettingAmount);
            // 更新用户金币
            //}else{
            //    appUser.setCoin(appUser.getCoin() + bettingAmount);
            //        if(appUser.getRole() == 1){
            //            appUser.setCoinCash(appUser.getCoinCash() + bettingAmount);
            //        }
            //}

            //appUserService.updateAppUser(appUser);

            //redisCache.deleteObject("U:UserInfo:" + appUser.getUserid());

            appGameBetting.setIsWinning(1);
            appGameBettingService.updateById(appGameBetting);

            FinTranRecord finTranRecord = new FinTranRecord();

            //finTranRecord.setAfterCoin(appUser.getCoin());
            //finTranRecord.setAfterDiamondCoin(appUser.getDiamondCoin());

            if(appGameBetting.getBettingType() == 0){
                finTranRecord.setCurrencyType(4);
                finTranRecord.setDiamondCoinChange(bettingAmount);
                finTranRecord.setCoinChange(0.00);
            }else{
                finTranRecord.setCurrencyType(2);
                finTranRecord.setCoinChange(bettingAmount);
                finTranRecord.setDiamondCoinChange(0.00);
            }

            finTranRecord.setAfterMoney(0.00);
            finTranRecord.setMoneyChange(0.00);

            finTranRecord.setAfterTicket(0.00);
            finTranRecord.setTicketChange(0.00);

            finTranRecord.setToUid(appUser.getUserid());
            finTranRecord.setUid(appUser.getUserid());

            finTranRecord.setSceneId1(0L);
            finTranRecord.setSceneId2(null);
            finTranRecord.setSceneType(0L);

            finTranRecord.setTranGroupId(appGameBetting.getId());

            if(appGameBetting.getBettingType() == 0){
                finTranRecord.setTranType1(FinTranType1.U_Income_Coin_Balance.getType());
            }else{
                finTranRecord.setTranType1(FinTranType1.U_Income_Coin.getType());
            }

            finTranRecord.setTranType2(FinTranType2.GAME_REWARD.getType());
            finTranRecord.setTranType3(FinTranType3.CHARGE_WIN_GAME.getType());

            finTranRecord.setRemarks("游戏中奖");

            finTranRecord.setConsumptionCoin(appGameBetting.getBettingAmount());
            finTranRecord.setConsumptionMoney(0.00);
            finTranRecord.setCommissionRelatedUid(0L);
            finTranRecord.setAgentId(appUser.getAgentId());

            finTranRecord.setCreateTime(new Date());

            finTranRecord.setFromUid(appGameBetting.getUserId());
            finTranRecord.setGoodsId(0L);
            finTranRecord.setGuildId(0L);
            finTranRecord.setManagerCoId(0L);
            finTranRecord.setManagerId(0L);

            finTranRecord.setPerc(0.00);
            finTranRecord.setProId(0L);
            finTranRecord.setProCount(0L);

            finTranRecord.setOrderId(appGameBetting.getId());
            //finTranRecordService.insertFinTranRecord(finTranRecord);
            appUserService.updateUserAmount(finTranRecord);
        }
        return userIds;
    }

    public void sendMsg(List<String> userIdList){
        if(userIdList == null || userIdList.isEmpty()){
            return;
        }

        JSONObject paramJson = new JSONObject();
        paramJson.put("type", "UserSystemNotify");
        paramJson.put("subType", "UserRefreshBalance");
        paramJson.put("content", JSONObject.parseObject("{'msg':'刷新余额'}"));

        List<String> sendUsers = new ArrayList<>();
        if(userIdList.size() > 500){
            for(String userId : userIdList){
                if(sendUsers.size() >= 500){
                    TencentCloudImUtil.imPushBatchSendMsg(sendUsers, paramJson.toString());
                    sendUsers.clear();
                }
                sendUsers.add(userId);
            }
            // 剩余不超过500
            if(!sendUsers.isEmpty()){
                TencentCloudImUtil.imPushBatchSendMsg(sendUsers, paramJson.toString());
            }
        }else{
            TencentCloudImUtil.imPushBatchSendMsg(userIdList, paramJson.toString());
        }
    }
}
